﻿
******** IMPORT DATA - SPSS <2012-11-24 richter@demogr.mpg.de>
******** SPSS Syntax to import the MOSAIC data into SPSS.
********
******** Overview:
******** The script imports the MOSAIC data file into an
******** SPSS data set named "mosaic_data". The script assigns labels and
******** marks missing values.
********
******** Usage:
******** Before opening this script in SPSS switch SPSS character encoding to
******** Unicode (SET UNICODE yes).
******** In line 25 insert the path to the mosaic datafile.
********
******** Details:
******** SPSS will truncate value labels longer than 120 characters in length.
********
******** Additional information:
******** This text file is originally encoded in UTF-8. The codes and labels
******** correspond to MOSAIC data harmonization version 1.6.

**** INIT.

* set the path to the MOSAIC .dat datafile.
File handle mosaic_data /name="N:\Mosaic\Data\Datafile_12\02_Final\Datafile_12 Version 1.0a_codes.csv".

**** INPUT.

*** define column positions, variable names, variable types and read mosaic data file.

GET DATA
/TYPE=TXT
/FILE="mosaic_data"
/DELCASE=LINE
/DELIMITERS=";"
/ARRANGEMENT=DELIMITED
/FIRSTCASE=2
/IMPORTCASE=ALL
/VARIABLES=
id_enum F6
country F3
year F4
enumtype F2
id_pers F15
id_hhold F14
qhhold F1
fname A32
lname A32
relateor A45
relate F4
qrelate F1
age F3
qage F1
sex F1
qsex F1
marst F1
qmarst F1
relig F4
lit F1
occupat A30
occhisco F5
hhsize F4
place F15
region F6
perwt F4.2
hhwt F4.2
gq F1
urban F1
presence F1.
CACHE.
EXECUTE.
DATASET NAME mosaic_data WINDOW=FRONT.

**** RESTRUCT.

*** define and apply variable labels.

VARIABLE LABELS
id_enum "enumeration identification number"
country "country code"
year "year of enumeration"
enumtype "type of enumeration"
id_pers "person identification number"
id_hhold "household identification number"
qhhold "quality flag household"
fname "first name"
lname "last name"
relateor "relationship to household head original"
relate "relationship to household head"
qrelate "quality flag household relationship"
age "age"
qage "quality flag age"
sex "sex"
qsex "quality flag sex"
marst "marital status"
qmarst "quality flag marital status"
relig "religion"
lit "literacy"
occupat "occupational title"
occhisco "occupational code in OCCHISCO"
hhsize "household size"
place "place code"
region "region"
perwt "person weight"
hhwt "household weight"
gq "group quarter status"
urban "urban-rural"
presence "presence of person at enumeration".

*** define and apply value codes, value labels and missing values for each variable.

VALUE LABELS id_enum
643201 "Russia 1814 private enumeration"
380050 "Venice 1724 enumeration"
250015 "France 1906 census"
642005 "Wallachia 1838 census"
643102 "Russia Roman Catholic confessional lists"
380210 "Ancient Roman census"
276311 "Calenberg-Göttingen-Grubenhagen 1689 head tax list"
643015 "Russia 1795 revision list"
643017 "Russia 1816 revision list"
643001 "Russia 1897 census"
040201 "Austria 17-18th century list of inhabitants"
250032 "France 1811 census"
368101 "Babylonian slave counts"
056020 "Belgium 1814 census"
440010 "Lithuania 1764 Jewish census"
156010 "Ancient China population register"
040001 "Austria 1857 census"
040002 "Austria-Hungary 1869 census"
040003 "Austria-Hungary 1880 census"
040004 "Austria-Hungary 1890 census"
040005 "Austria-Hungary 1900 census"
040006 "Austria-Hungary 1910 census"
040010 "Austria 1850 conscription"
040020 "Albania 1918 census"
040101 "Austria 17-18th c. Status Animarum"
100201 "Bulgarian registers Rhodope mountains"
191101 "Dubrovnik 1674 Status Animarum"
208001 "Schleswig-Holstein 1769 census"
208002 "Schleswig-Holstein 1787 census"
208003 "Schleswig-Holstein 1801/1803 census"
208004 "Schleswig-Holstein 1835 census"
208005 "Schleswig-Holstein 1840 census"
208006 "Schleswig-Holstein 1845 census"
208007 "Schleswig-Holstein 1850 census"
208008 "Schleswig-Holstein 1855 census"
208009 "Schleswig-Holstein 1860 census"
208010 "Schleswig-Holstein 1864 census"
250001 "France 1836 census"
250002 "France 1841 census"
250003 "France 1846 census"
250004 "France 1851 census"
250005 "France 1856 census"
250006 "France 1861 census"
250007 "France 1866 census"
250008 "France 1872 census"
250009 "France 1876 census"
250010 "France 1881 census"
250011 "France 1886 census"
250012 "France 1891 census"
250013 "France 1896 census"
250014 "France 1901 census"
250036 "France 1831 census"
276001 "Mecklenburg-Schwerin 1819 census"
276011 "German Customs Union 1835 census"
276012 "German Customs Union 1840 census"
276013 "German Customs Union 1843 census"
276014 "German Customs Union 1846 census"
276015 "German Customs Union 1849 census"
276016 "German Customs Union 1852 census"
276017 "German Customs Union 1855 census"
276018 "German Customs Union 1858 census"
276019 "German Customs Union 1861 census"
276020 "German Customs Union 1864 census"
276021 "German Customs Union 1867 census"
276031 "German Empire 1871 census"
276032 "German Empire 1875 census"
276033 "German Empire 1880 census"
276034 "German Empire 1885 census"
276035 "German Empire 1890 census"
276036 "German Empire 1895 census"
276037 "German Empire 1900 census"
276038 "German Empire 1905 census"
276039 "German Empire 1910 census"
276110 "Münster 1749/50 Status Animarum"
276111 "NW Germany Status Animarum"
276120 "Konstanz 1774 Status Animarum"
276121 "Freiburg region Status Animarum"
276122 "Speyer region Status Animarum"
276201 "NW Germany list of communicants"
276301 "NW Germany list of inhabitants"
380101 "Rome Status Animarum"
380201 "Legnago 1430-32 enumeration"
616101 "Poland-Lithuania listings"
688008 "Serbia 1863 census"
688012 "Serbia 1884 census"
724101 "Spain 1752 Catastro de Ensenada"
756101 "Switzerland church listings"
792001 "Istanbul 1885 census"
792002 "Istanbul 1907 census"
203101 "Leitmeritz/Litoměřice 1669 Status Animarum"
643211 "Russia listings of state estate households"
643212 "Russia listings of private estate households"
688101 "Serbian Orthodox Status Animarum".
MISSING VALUES id_enum ().

VALUE LABELS country
818 "Egypt"
368 "Iraq"
156 "China"
008 "Albania"
020 "Andorra"
040 "Austria"
056 "Belgium"
070 "Bosnia and Herzegovina"
100 "Bulgaria"
112 "Belarus"
191 "Croatia"
196 "Cyprus"
200 "Czechoslovakia"
203 "Czech Republic"
208 "Denmark"
233 "Estonia"
234 "Feroe-Islands"
246 "Finland"
250 "France"
276 "Germany"
300 "Greece"
336 "Vatican"
348 "Hungary"
352 "Iceland"
372 "Ireland"
380 "Italy"
428 "Latvia"
438 "Liechtenstein"
440 "Lithuania"
442 "Luxembourg"
470 "Malta"
492 "Monaco"
498 "Moldavia"
499 "Montenegro"
528 "Netherlands"
578 "Norway"
616 "Poland"
620 "Portugal"
642 "Romania"
643 "Russia"
688 "Serbia"
703 "Slovakia"
705 "Slovenia"
724 "Spain"
752 "Sweden"
756 "Switzerland"
792 "Turkey"
804 "Ukraine"
807 "Macedonia"
810 "USSR"
826 "United Kingdom"
891 "Yugoslavia"
999 "unknown".
MISSING VALUES country (999).

VALUE LABELS year
9999 "unknown".
MISSING VALUES year (9999).

VALUE LABELS enumtype
13 "ancient census"
31 "head tax list"
32 "revision list"
23 "confessional list"
43 "household register"
33 "other tax list"
24 "soul register"
44 "list of slaves"
10 "census (unknown whether de jure or de facto)"
11 "de jure census"
12 "de facto census"
21 "status animarum"
22 "list of communicants"
41 "list of inhabitants"
99 "unknown"
42 "conscription list".
MISSING VALUES enumtype (99).

VALUE LABELS id_pers.
MISSING VALUES id_pers ().

VALUE LABELS id_hhold.
MISSING VALUES id_hhold ().

VALUE LABELS qhhold
5 "incomplete household"
0 "household status not altered"
1 "household status altered: combining two or more households"
2 "household status altered: one household separated into more households"
3 "household with strange characteristics"
6 "household borders changed"
7 "group quarter without head".
MISSING VALUES qhhold ().

VALUE LABELS fname
"!!" "missing first name"
"??" "illegible first name"
"**" "first name not included in data file".
MISSING VALUES fname ("!!" "??" "**").

VALUE LABELS lname
"!!" "missing last name"
"??" "illegible last name"
"**" "last name not included in data file".
MISSING VALUES lname ("!!" "??" "**").

VALUE LABELS relateor
"!!" "missing relationship to household head"
"??" "illegible relationship to household head"
"**" "relationship to household head not included in data file".
MISSING VALUES relateor ("!!" "??" "**").

VALUE LABELS relate
1225 "spouse of employee"
1226 "child of employee"
1229 "slave"
0608 "retired person's grandchild"
0101 "head/householder"
0201 "spouse"
0202 "2nd/3rd wife (polygamous)"
0203 "concubine/mistress"
0301 "child"
0302 "adopted child"
0303 "stepchild"
0304 "adopted, n.s."
0305 "adopted/fostered child (Great Britain)"
0306 "fostered child"
0401 "child-in-law"
0402 "step child-in-law"
0501 "parent"
0502 "stepparent"
0503 "adoptive parent"
0601 "parent-in-law"
0602 "stepparent-in-law"
0603 "retired people with special benefits from farm (karfolk)"
0605 "retired person (last name of this person or its spouse is the same as the last name of the household head or head’s spouse)"
0606 "retired person’s spouse"
0607 "retired person’s child"
0701 "sibling"
0702 "step/half/adopted sibling"
0703 "step sibling"
0704 "half-sibling"
0801 "sibling-in-law"
0802 "step/half sibling-in-law"
0901 "grandchild"
0902 "adopted grandchild"
0903 "step grandchild"
0904 "grandchild-in-law"
1001 "other relatives, not specified"
1011 "grandparent"
1012 "step grandparent"
1013 "grandparent-in-law"
1021 "aunt or uncle"
1022 "aunt, uncle-in-law"
1023 "step aunt or uncle"
1024 "great aunt or uncle"
1031 "nephew, niece"
1032 "nephew/niece-in-law"
1033 "step/adopted nephew/niece"
1034 "grand niece/nephew"
1035 "step nephew/niece"
1036 "adopted nephew/niece"
1037 "grand step nephew/niece"
1038 "grand nephew/niece-in-law"
1041 "cousin"
1042 "cousin-in-law"
1043 "first cousin"
1044 "second cousin"
1051 "great grandchild"
1061 "other relatives, not elsewhere classified"
1100 "partner, friend, visitor"
1110 "partner/friend"
1111 "friend"
1112 "partner"
1113 "partner/roommate"
1114 "unmarried partner"
1115 "housemate/roommate"
1120 "relative of partner"
1131 "visitor"
1132 "companion and companion’s family"
1139 "allocated partner/friend/visitor"
1141 "retired person (last name of this person or its spouse is different from the last name of the household head or head’s spouse)"
1142 "retired person’s spouse"
1143 "retired person’s child"
1144 "retired person’s grandchild"
1145 "retired person’s parent"
1146 "retired person’s child-in-law"
1147 "retired person’s other relative"
1200 "other non-relatives"
1201 "roomers/boarders/lodgers"
1202 "boarders"
1203 "lodgers"
1204 "roomer"
1205 "tenant"
1206 "spouse of roomers/boarders/lodgers/tenants"
1207 "children of roomers/boarders/lodgers/tenants"
1208 "pauper (staying with others at expense of municipality)"
1209 "other relative of roomers/boarders/lodgers/tenants"
1210 "employees"
1211 "servant"
1212 "housekeeper"
1213 "maid"
1214 "cook"
1215 "nurse"
1216 "other probable domestic employee"
1217 "other employees"
1218 "apprentice, journeyman"
1219 "relative of employee"
1221 "military"
1222 "students"
1223 "members of religious orders"
1230 "other non-relatives"
1239 "allocated other non-relatives"
1301 "institutional inmates"
1302 "families of inmates"
1303 "foundlings/orphans"
9993 "the same as the previous entry"
9994 "numbered item (indicates being the same as the previous entry)"
9995 "not coded yet"
9996 "unclassifiable"
9997 "unknown"
9998 "illegible"
9999 "missing".
MISSING VALUES relate (9993 THRU HI).

VALUE LABELS qrelate
0 "relationship status not altered"
1 "relationship status altered because relationship refers not to household head"
2 "relationship status altered because it is obviously wrong"
3 "relationship status altered because no household head was enumerated"
4 "relationship status altered because of more than one household head"
5 "relationship status altered because of information from other members of the household"
6 "relationship status alterd because person is a member of a larger household, but we don't know this household".
MISSING VALUES qrelate ().

VALUE LABELS age
131 "nursing"
132 "weaned"
133 "child"
134 "adolescent"
135 "adult"
136 "old"
0 "less than 1 year old"
999 "unknown".
MISSING VALUES age (999).

VALUE LABELS qage
0 "age not altered"
1 "age altered because of inconsistency with other characteristics"
2 "age altered because over 125 years".
MISSING VALUES qage ().

VALUE LABELS sex
1 "male"
2 "female"
8 "illegible"
9 "missing/blank".
MISSING VALUES sex (8 9).

VALUE LABELS qsex
0 "sex not altered"
1 "sex altered because relationship and first name imply different sex"
2 "sex altered on basis of first name only".
MISSING VALUES qsex ().

VALUE LABELS marst
1 "married, spouse present"
2 "married, spouse absent"
3 "separated"
4 "divorced"
5 "widowed"
6 "never married/single"
7 "unmarried union"
9 "indeterminate/unknown, blank, or missing".
MISSING VALUES marst (9).

VALUE LABELS qmarst
0 "marital status not altered"
1 "marital status altered".
MISSING VALUES qmarst ().

VALUE LABELS relig
6130 "Armenian Catholic"
6360 "Unitarian"
6210 "Old Believer"
0000 "not recorded"
1000 "no religion"
1001 "Atheist"
1002 "Without religion"
2000 "Buddhist"
3000 "Hindu"
4000 "Jewish"
5000 "Muslim"
6000 "Christian"
6100 "Catholic"
6110 "Roman Catholic"
6120 "Greek Catholic"
6200 "Orthodox"
6300 "Protestant"
6310 "Lutheran"
6320 "Anglican"
6330 "Reformed"
6340 "Pentecostal"
6350 "Adventist/Seventh-day adventist"
6400 "other Christian"
7000 "Other"
7001 "Bahai"
7002 "Sikh"
9999 "unknown".
MISSING VALUES relig (0000 9999).

VALUE LABELS lit
0 "not recorded"
1 "illiterate"
2 "can't read, can write"
3 "can't write, can read"
4 "literate"
9 "unknown".
MISSING VALUES lit (0 9).

VALUE LABELS occupat
"!!" "missing occupational title"
"??" "illegible occupational title"
"**" "occupational title not included in data file".
MISSING VALUES occupat ("!!" "??" "**").

VALUE LABELS occhisco
01100 "Chemists"
01200 "Physicists"
01300 "Physical scientists nec"
01400 "Physical science assistants and technicians"
02000 "Professional engineers, specialisation unknown"
02100 "Architects"
02200 "Civil engineers"
02300 "Electrical engineers"
02410 "Mechanical engineers, general or nfs"
02420 "Industrial machinery or tools engineers"
02430 "Mechanical engineer (motors and engines, except marine)"
02440 "Marine engineers"
02450 "Ship construction engineers"
02460 "Heating, ventilation and refrigeration engineers"
02490 "Other mechanical engineers"
02500 "Chemical engineers"
02600 "Metallurgists and assayers"
02700 "Mining engineers"
02800 "Industrial engineers"
02900 "Professional engineers nec"
03010 "Surveyors, general and nfs"
03020 "Land surveyors"
03030 "Mine surveyors"
03040 "Hydrographic surveyors"
03090 "Other surveyors"
03100 "Draughtsmen"
03210 "Technicians"
03220 "Civil engineering technicians"
03230 "Electrical engineering technicians"
03240 "Mechanical engineering technicians"
03250 "Chemical engineering technicals"
03260 "Metallurgical technicians"
03270 "Mining technicians"
03290 "Engineering technicians nec"
04200 "Ship's deck officer or pilot"
04210 "Ships officers nfs"
04220 "Ship's masters and captains (sea)"
04230 "Ship's masters and captains (sea or inland waterways)"
04240 "Ship's masters and captains (inland waterways)"
04250 "Ship's navigating officers and ship's mates"
04260 "Ship and boat pilots"
04270 "Marine superintendents (deck)"
04290 "Other ship deck officers and pilots"
04300 "Ship's engineers"
05100 "Biologists, botanists, zoologists and related scientists"
05200 "Medical scientists"
05300 "Agronomists and related scientists"
05400 "Life sciences technicians"
06110 "Medical doctors and physicians (UK: Medical doctors only)"
06130 "Surgeons"
06140 "Specialised physicians"
06150 "Specialised surgeons"
06160 "Public health physicians"
06170 "Oculist"
06190 "Medical doctors, nec"
06200 "Dentists"
06300 "Veterinarians"
06400 "Pharmacists"
06500 "Medical and related assistants"
07110 "Trained nurses"
07210 "Nurses nfs"
07220 "Medical nurses, untrained or level of training unknown"
07320 "Midwives"
07330 "Monthly nurses"
07500 "Opticians and optometrists"
07600 "Healers and therapists nec"
07920 "Osteopaths"
07930 "Chiropractors"
07940 "Sanitarians"
07990 "Other Medical, Dental, Veterinary and Related Workers"
08000 "Mathematicians and actuaries, etc."
09000 "Economists"
11010 "Accountants"
11020 "Auditors"
11090 "Accountants nec"
12110 "Lawyers"
12120 "Barristers"
12130 "Solicitors"
12200 "Judge"
12220 "Justice of the Peace"
12300 "Notary"
12900 "Jurists (except Lawyer, Judge or Solicitor)"
13100 "Teachers in higher education"
13210 "Teachers (unspecified)"
13220 "Teachers (secondary)"
13230 "Teachers (primary)"
13240 "Teachers (pre-primary)"
13250 "Teachers (of the disabled)"
13300 "School administrators and principals"
13920 "Governesses"
13990 "Other teaching personnel"
14120 "Ministers of religion"
14130 "Missionaries"
14140 "Members of religious orders"
14190 "Other ministers of religion"
14900 "Workers in religion nec"
15100 "Authors"
15220 "Editors"
15230 "Journalists, reporters and correspondents"
15900 "Others writers"
16110 "Artists nfs and art teachers"
16120 "Sculptors"
16130 "Artistic Painters"
16140 "Cartoonists"
16150 "Engravers and etchers (artistic)"
16190 "Other specified creative artists"
16200 "Designers"
16300 "Photographers"
16400 "Engravers"
17120 "Musical performers and musicians nfs"
17130 "Music teachers"
17190 "Others in music"
17200 "Dancers and dancing teachers"
17300 "Actors and related workers"
17400 "Producers, performing arts"
17900 "Performing artists nec"
18000 "Athletes, sportsmen and related workers"
19100 "Librarians, archivists and curators"
19200 "Social scientists and historians"
19300 "Social workers"
19500 "Interpreters, translators and philologists"
19920 "Patent Agents"
19930 "Underwriters"
19990 "Other professional, technical and related workers nec"
20100 "Legislative officials and heads of government"
20200 "Government administrators"
21110 "Proprietors, nfs"
21112 "Executive officers, nfs (U.S. only)"
21120 "Manufacturers nfs"
21122 "Executive officers of manufacturing concerns nfs"
21130 "Manufacturers or proprietors of specified manufacturing concerns"
21132 "Executive officers of specified manufacturing concerns"
21140 "Proprietor, mining, quarrying, oil and natural gas extraction"
21141 "Oil Producer"
21142 "Executive officers of extractive industry"
21150 "Proprietor, railway company"
21152 "Executive officers of railway concerns"
21160 "Proprietor, other transport and communications"
21162 "Executive officer of other transport and communications"
21170 "Proprietor, public utilities (i.e., water, gas, etc.)"
21172 "Executive officer of public utilities"
21180 "Proprietor, finance"
21182 "Executive officer finance company"
21190 "Other owners of large scale productive enterprises"
21192 "Executive officers of other large scale productive enterprises"
21194 "Publisher"
21210 "Contractors nfs"
21220 "Construction contractors"
21230 "Builders"
21290 "Other specified contractors"
21330 "Capitalists"
21340 "Speculators"
21390 "Investors nec"
22110 "Superintendents and managers nfs"
22120 "Superintendents and managers, manufacturing"
22130 "Superintendents and managers, mining, quarrying, etc."
22140 "Superintendents and managers, railways"
22150 "Superintendents and managers, other transport and communications"
22160 "Superintendents and managers, public utilities"
22170 "Superintendents and managers, construction, except railway construction"
22180 "Superintendents and managers, commerce"
22190 "Superintendents and managers, nec"
23110 "Foremen and supervisors nfs"
23120 "Foremen and supervisors, manufacturing"
23130 "Foremen and supervisors, mining"
23140 "Foremen and supervisors, railways"
23150 "Foremen and supervisors, other transport and communications"
23160 "Foremen and supervisors, public utilities"
23170 "Foremen and supervisors, construction, except railway construction"
23180 "Foremen and supervisors, commerce"
23190 "Foremen and supervisors, nec"
24100 "Inspectors of manufactories, companies etc."
31010 "Civil servants, title unknown"
31020 "Tax collectors"
31030 "Tax assessors"
31040 "Customs officers"
31050 "Postmasters or postmistresses"
31060 "Clerks of court and other court clerks"
31090 "Government functionaries, nec"
32000 "Typists, stenographers and secretaries"
33120 "Bookkeepers and bookkeeping clerks"
33130 "Cashiers, bank or office"
33140 "Bank clerks"
33142 "Bank tellers (US)"
33150 "Money collector"
33160 "Cash desk cashier"
33170 "Toll collectors"
33180 "Collector (cash or account)"
33190 "Bookkeeping, account and cash handling workers nec"
33210 "Railway clerks (UK) and railway agents (CA/US)"
33220 "Baggage agents and baggage men"
33320 "Agent, water transport (principally steamship and steamboat)"
33330 "Agent, land transport (non-rail)"
34000 "Office machine operators"
36010 "Conductors, nfs"
36020 "Railway guards (UK) and Railroad Conductors (US/CAN)"
36030 "Sleeping- or pullman-car attendants"
36040 "Bus, tram or streetcar conductors"
36090 "Transport conductors, nec"
37020 "Postal, mail and telegraph clerks"
37030 "Mail carriers aka Postmen (UK)"
37040 "Messengers"
37050 "Mail sorters"
37090 "Post office, mail, and message workers nec"
38010 "Tel. operator"
38020 "Telephone operator"
38030 "Telegraph operator"
38090 "Other telephone/telegraph operators"
39000 "Clerk, nfs"
39100 "Stock, weight and shipping clerks"
39130 "Stock records clerk"
39310 "Office clerks, specialisation unknown"
39320 "Correspondence clerks"
39340 "Legal clerks"
39350 "Insurance clerks"
39390 "Other correspondence and reporting clerks"
39400 "Hotel clerk or other receptionist"
39500 "Library and filing clerks"
39600 "Railroad, railway clerk"
39720 "Timekeepers, railway"
39730 "Timekeepers, factory"
39790 "Timekeepers, undefined and nec"
39900 "Other specified clerks"
39990 "Proofreader (U.S. only)"
40000 "Sales workers, nfs"
41000 "Working proprietors, nfs"
41010 "Dealer, merchant etc. (Wholesale and retail trade)"
41015 "Merchants, specified large-scale wholesaleing"
41020 "Hirers out"
42000 "Buyers"
43010 "Agents nfs"
43020 "Commercial travellers"
43030 "Manufacturers and sales agents"
43090 "Other specialized agents"
44110 "Insurance, real state or securities salesmen, nfs"
44120 "Insurance salesmen and agents"
44130 "Real estate agents"
44140 "Brokers"
44150 "Stockbrokers"
44160 "Patent Agents"
44190 "Insurance, real estate and securities salesmen nec"
44200 "Advertising salesmen"
44320 "Auctioneers"
44330 "Appraisers"
45120 "Salespeople, wholesale or retail trade"
45130 "Clerks in shops and stores"
45140 "Fashion models"
45190 "Other sales personnel men, shop assistants and demonstrators"
45220 "Street sellers, pedlars and hawkers, non-food items"
45230 "Street sellers, pedlars and hawkers, food items"
45240 "Newsvendors"
45250 "Canvassers"
45290 "Other street traders for coffee and food"
49020 "Pawnbrokers"
49030 "Scrap and junk dealers, scavengers"
49090 "Dealers and salesworkers nec"
51020 "Hotel keepers and managers"
51030 "Restaurant keepers and managers"
51040 "Boarding and lodging house keepers and managers"
51050 "Pub, saloon, tavern and coffee house keepers"
51060 "Ship's pursers"
51090 "Other hospitality and entertainment keepers and managers"
52020 "Housekeeper"
52030 "Stewards"
52040 "Matrons"
52050 "Butlers"
52090 "Other housekeeping service supervisors"
53100 "Cooks"
53101 "Cook (Domestic) UK only"
53103 "Ship's cooks"
53220 "Waiter or waitress"
53230 "Bartender"
53290 "Other food and drink service workers"
54010 "Servants nfs"
54020 "House servants nfs and maids"
54030 "Personal servants and valets"
54040 "Nursemaids"
54050 "Companions"
54060 "Chambermaids and room attendants"
54090 "Other specified servants"
55100 "Caretakers and janitors"
55200 "Charworkers"
55230 "Window cleaners"
55240 "Chimney sweeps"
55250 "Refuse collectors and removers"
55290 "Other charworkers, cleaners and related workers"
56000 "Washing and laundry services"
57020 "Hairdressers"
57030 "Barbers"
57040 "Bath attendants"
57090 "Other barbers, hairdressers and related workers"
58100 "Firefighters"
58210 "Policemen and detectives, employer unknown"
58220 "Policemen and detectives, public service"
58230 "Policemen and detectives, private service"
58240 "Sheriffs and their deputies"
58290 "Other law enforcement officers"
58300 "Watchmen and guards"
58410 "Military, rank unknown"
58420 "Military officers"
58430 "Other members of the armed forces"
58500 "Prison keepers and guards"
58900 "Other protective service workers"
59100 "Guides"
59200 "Undertakers and embalmers"
59300 "Prostitutes"
59920 "Bookmakers (sport)"
59930 "Croupiers"
59940 "Nursing aids and attendents"
59950 "Errand boys and errand girls"
59960 "Practical Aid (Veterinary)"
59990 "Other Service Workers nec"
61110 "General farmers and farmers nfs"
61115 "Husbandmen or cottars"
61117 "Female farmer"
61120 "Major landowner"
61220 "Field crop farmers"
61230 "Orchardists and fruit farmers"
61240 "Market gardeners"
61250 "Nurserymen and florists"
61260 "Livestock farmers"
61270 "Dairy farmers"
61280 "Poultry farmers"
61290 "Other specialised farmers"
61320 "Farmer and Fisherman"
61330 "Cottar and Fisherman"
61400 "Farm managers, formen and supervisors nfs"
62110 "Farm workers, specialisation unknown"
62113 "Farmer's sons and other male relatives"
62200 "Farm workers (field crop and vegetables)"
62300 "Farm labourers, orchard and fruit farm workers"
62410 "Livestock workers, general or nfs"
62420 "Cattle workers, except specified dairy"
62430 "Sheep workers"
62440 "Pig workers"
62450 "Fur-bearing animal workers"
62460 "Horse workers"
62461 "Grooms and horse keepers (Domestic)"
62463 "Grooms and horse keepers (Not domestic)"
62470 "Horse breaker"
62490 "Livestock workers, nec"
62500 "Farm workers (dairy)"
62600 "Farm workers (poultry)"
62710 "Gardeners nfs"
62711 "Gardener (Domestic)"
62713 "Gardener (Not domestic)"
62720 "Market garden labourers"
62730 "Nursery labourers"
62740 "Landscape gardeners"
62790 "Other nursery workers and gardeners"
62800 "Farm machinery operators"
62920 "Other animal workers e.g., dogs, elephants"
62930 "Other plant workers e.g., gathers of herbs etc."
62940 "Groundskeepers, etc."
62990 "Others in agricultural or husbandry"
63110 "Woodsmen and workers in the woods, nfs"
63120 "Lumbermen, loggers and kindred workers"
63130 "River drivers"
63140 "Wood cutters and choppers"
63190 "Others in logging and wood cutting"
63220 "Foresters and wood wardens"
63230 "Forestry workers"
63240 "Timber cruisers"
63250 "Forest fire-fighters"
63290 "Other forestry workers"
64100 "Fishermen"
64920 "Fish farm workers"
64930 "Oyster farm workers"
64940 "Whale hunters"
64950 "Whale or seal hunters"
64960 "Seal hunters"
64970 "Trappers or hunters"
64990 "Other fishermen, hunters and related workers"
71120 "Miners"
71130 "Quarrymen"
71190 "Others working in mines and quarries"
71200 "Mineral or stone treaters"
71300 "Well drillers, borers and related workers"
72000 "Metal workers, specialisation unknown"
72100 "Metal smelter and furnacemen"
72200 "Metal rollers"
72300 "Metal melters and reheaters, and workers in metal melting mills"
72400 "Metal casters and workers in metal casting plants"
72500 "Metal moulders and coremakers"
72600 "Metal annealers, temperers and hardeners"
72700 "Metal drawers and workers in metal drawing"
72800 "Metal platers and coaters"
72900 "Other (specialised) metal workers"
73100 "Wood treaters"
73200 "Sawyers and other titled wood/sawmill operatives"
73300 "Papermill machine operators and paper makers"
74000 "Chemical workers, product nfs"
74100 "Drug workers"
74200 "Gunpowder and explosive makers"
74320 "Charcoal burners"
74330 "Coal gas makers"
74340 "Tar makers"
74390 "Other coal product makers e.g., coke"
74420 "Salt makers"
74430 "Alkali and soda makers"
74500 "Oil mill workers"
74620 "Paint and varnish makers"
74630 "Dye makers"
74640 "Ink, blacking, colouring, etc., makers"
74720 "Tallow chandlers, candle makers and grease makers"
74730 "Soap and perfume makers"
74740 "Glue, size and gelatine makers"
74750 "Wax and polish makers"
74920 "Fertilizer and manure makers"
74930 "Starch makers"
74940 "Turpentine makers"
74990 "Specified chemical workers nec"
75000 "Textile workers, specialisation unknown"
75100 "Fibre preparers"
75200 "Spinners, doublers, twisters and winders"
75300 "Weaving and knitting-machine setters and pattern-card preparers"
75400 "Weavers"
75500 "Knitters"
75600 "Bleachers, dyer or textile product finisher"
75700 "Rope makers"
75920 "Net maker"
75990 "Other specialised textile workers nec"
76110 "Tanners or fellmongers, specialisation unknown"
76120 "Fellmongers"
76130 "Tanners"
76140 "Leather curriers and finishers"
76190 "Other specified leather curers"
76200 "Fur and pelt dressers"
77100 "Millers and related workers"
77200 "Sugar refiners"
77310 "Butchers"
77320 "Pork butchers"
77340 "Slaughterer, meat cutters or meat packer"
77350 "Sausage makers"
77360 "Fish butchers"
77380 "Meat cannery workers and other meat preservers (not sausages)"
77390 "Other workers in meat preparation"
77400 "Cannery workers and other food preservers"
77500 "Butter, cheese and dairy product makers"
77610 "Baker and confectioner"
77620 "Bakers"
77630 "Confectioners and pastry makers"
77640 "Candy makers"
77650 "Chocolate makers"
77690 "Other baked goods makers"
77700 "Tea, coffee and cocoa preparers"
77820 "Brewers"
77830 "Maltsters"
77840 "Wine workers"
77850 "Vinegar makers and workers"
77860 "Distillers"
77870 "Makers of soft drinks"
77880 "Bottlers"
77890 "Other drinks makers and workers"
77990 "Other food and beverage processors"
78100 "Tobacco preparers and tobacco factory workers"
78200 "Cigar makers"
78300 "Cigarette makers"
78400 "Other tobacco product makers"
79120 "Tailors and tailoresses"
79130 "Dressmakers"
79190 "Other garment makers"
79200 "Furriers and fur workers"
79320 "Milliners"
79330 "Hat makers"
79340 "Straw hat makers"
79390 "Other hat makers"
79400 "Glove makers and related workers"
79520 "Seamstresses"
79530 "Sewers and sewing machine operators"
79540 "Embroiderers"
79590 "Others hand sewers"
79620 "Upholsterers (except vehicle)"
79630 "Vehicle trimmers and upholsterers"
79640 "Mattress makers"
79690 "Others working in upholstery jobs"
79920 "Sail, tent and awning makers"
79930 "Umbrella makers"
79940 "Artificial flower makers"
79990 "Other cloth and related product manufacturing workers"
80100 "Boot and shoe makers and repairers"
80200 "Specialised occupations in the boot and shoe making industry"
80320 "Saddlers and harness makers"
80330 "Trunk or bag maker"
80390 "Other leather goods makers"
81120 "Cabinet makers"
81130 "Chair makers"
81140 "Wicker furniture makers"
81190 "Other furniture makers"
81210 "Woodworkers"
81220 "Sawyers, woodworking"
81230 "Wood turners and handle makers"
81240 "Wood planers"
81250 "Wood carvers"
81290 "Other woodworking machine operators"
81300 "Coach, carriage and wagon makers"
81400 "Wheelwrights and cartwrights"
81500 "Coopers, hoop makers and benders"
81600 "Clog makers"
81710 "Box makers nfs"
81720 "Wooden box makers"
81730 "Paper box makers"
81790 "Box makers nec"
81920 "Wooden tool makers"
81930 "Ski makers"
81990 "Other makers of wooden products"
82000 "Stone carvers or cutters and stone yard workers"
83120 "Blacksmiths"
83130 "Hammersmiths"
83140 "Foregemen"
83150 "Farriers or horseshoers"
83160 "Specialised makers of forged metal products"
83190 "Other blacksmiths, hammermen and forgeing-press operators"
83210 "Tool makers nfs"
83220 "Tool and die makers"
83230 "Pattern makers nfs and nec"
83290 "Other tool makers and metal markers"
83310 "Metalworking machine operators"
83320 "Metal Turners"
83390 "Other metal working machine operators"
83400 "Machinists"
83520 "Metal polishers and finishers"
83530 "Metal grinders and sharpeners"
83540 "Cutlers and cutting instrument makers"
83550 "Cutler (knives, forks, spoon)"
83590 "Other metal grinders, polishers and tool sharpeners nec"
83600 "Gunsmiths"
83700 "Locksmiths"
83820 "Saw makers"
83830 "Saw, spade, shovel and half wood/half metal agricultural instrument type things"
83840 "Chain makers"
83850 "Nailer and nail makers"
83860 "Wire makers"
83890 "Other metal workers nec"
84110 "Mechanics"
84120 "Millwrights"
84130 "Machine makers, builders and fitters"
84140 "Engine and locomotive builders"
84150 "Sewing machine makers and builders"
84190 "Other machinery fitters and machine assemblers"
84220 "Watch and clock makers"
84230 "Optical instrument makers and workers (not opticians)"
84290 "Other specialized instrument makers (not musical instrument makers)"
84300 "Bicycle makers"
84900 "Others in machinery"
85100 "Electrical fitters and electrical equipment assemblers"
85500 "Electricians and  wiremen"
85600 "Telephone and telegraph installers"
85700 "Linesmen: telephone, telegraph and electric"
85920 "Electrical products inspector or tester"
85990 "Other electrical fitters and related electrical workers"
87120 "Plumbers"
87130 "Pipe fitters"
87220 "Welders"
87230 "Braziers"
87250 "Flamecutter"
87290 "Other welders, braziers, solderers"
87320 "Sheet metal worker, general"
87330 "Coppersmith or copperware maker"
87340 "Tinsmith, tinner or tinker"
87350 "Boilermaker"
87390 "Other sheet metal workers"
87420 "Structural metal workers"
87430 "Rivetters nec"
87490 "Other structural metal preparers and erectors"
87520 "Ship and boat builders"
87530 "Shipwrights and ship joiners"
87540 "Ship's carpenters"
87550 "Block, mast and tackle makers"
87560 "Caulker"
87590 "Other ship builders"
88020 "Jewellers"
88030 "Goldsmith"
88040 "Silversmith"
88050 "Working with gems and stones"
88090 "Other jewellery and precious metal workers"
89120 "Glass makers"
89130 "Glass bottle makers"
89190 "Other specific glass makers"
89200 "Pottery and porcelain makers and workers"
89300 "Brick and tile makers"
89400 "Glass engravers, etchers and finishers"
89500 "Pottery and porcelain painters"
89620 "Cement makers"
89630 "Lime burners"
89700 "Clay-based products makers"
90100 "Rubber product makers"
90200 "Tire makers and vulcanisers"
91020 "Paper and paperboard products makers, except boxes"
91090 "Other paper product makers"
91100 "Paper and paper board product makers"
92000 "Printers nec"
92110 "Printers nfs"
92120 "Compositors"
92190 "Other compositors and typesetters"
92200 "Lithographic printers"
92300 "Stereotypers and electrotypers"
92400 "Lithographers"
92500 "Photo-engravers"
92600 "Bookbinders and related workers"
92800 "Textile printers"
92900 "Other printers and related workers"
93110 "Painters, nfs"
93120 "Painters, construction"
93130 "Painters, ship"
93190 "Other specialised painters nec"
93200 "Decorators"
93320 "Lacquerers and enamellers"
93330 "Japanners"
93400 "Gilders"
94110 "Musical instrument maker nfs"
94120 "Piano maker"
94130 "Piano tuner"
94140 "Organ builder"
94190 "Other musical instrument makers and tuner"
94220 "Basket makers"
94230 "Brush makers"
94240 "Broom makers"
94290 "Bristle and straw workers nec"
94300 "Non-metallic mineral product makers"
94910 "Other production or related worker, specialisation unknown"
94920 "Animal stuffers, taxidermists and shell workers"
94930 "Linoleum makers and floor cloth makers"
94940 "Toy and doll makers"
94990 "Production and related workers nec"
95110 "Mason nfs or combined"
95120 "Bricklayers"
95130 "Stone masons"
95140 "Plasterers"
95150 "Paviours"
95160 "Marble mason"
95190 "Others in construction"
95200 "Cement masons and finishers"
95310 "Roofer, specialisation unknown"
95320 "Slate and tile roofers"
95330 "Thatchers"
95390 "Other roofers"
95410 "Carpenter and joiner"
95420 "Carpenters"
95430 "Joiners"
95440 "Scaffolders"
95490 "Other wooden construction workers"
95600 "Pipe coverers and Insulators"
95700 "Glaziers"
95910 "Construction workers nec"
95920 "Paperhangers"
95930 "Carpet planners"
95940 "Whitewashers"
95950 "Demolition workers"
95960 "Marblers"
95990 "Others in building construction"
96100 "Electricity generators"
96220 "Engineers (US) nfs"
96230 "Stationary engineers and engine men"
96240 "Stationary firemen and firemen nfs"
96900 "Other stationary engine and related equipment operators"
97120 "Ship boat loaders and dock workers"
97130 "Railway freight handlers"
97140 "Porters"
97150 "Packers"
97190 "Other freight handlers"
97210 "Riggers nec or nfs"
97220 "Ship riggers"
97300 "Crane and hoist operators"
97410 "Navvy, excavator and diggers, nfs"
97420 "Road builders, workers and labourers"
97430 "Railway builders, workers and labourers"
97440 "Waterway and harbour builders, workers and labourers"
97490 "Other road, railway and related construction labourers"
97900 "Material handling equipment operators nec"
98120 "Seamen"
98130 "Boatmen and canalmen"
98190 "Other crew of boats, ships, etc."
98200 "Ship's engine men"
98320 "Railway/railroad engineers and enginemen"
98330 "Railway/railroad firemen and stokers"
98420 "Railway brakemen"
98430 "Railway signallers"
98440 "Railway switchmen and shunters"
98490 "Others skilled railway workers"
98510 "Drivers, nec"
98520 "Drivers (private)"
98530 "Drivers (personal, for hire)"
98540 "Drivers (public)"
98550 "Delivery men and drivers of goods"
98560 "Drivers (general haulage)"
98562 "Carter (agricultural)"
98570 "Teamsters (inc. mine driver, etc.)"
98590 "Others drivers"
98700 "Lock and gate keepers"
98720 "Lock keepers"
98730 "Gate keepers"
98900 "Other transport equipment operators"
99120 "Labourers nfs"
99130 "Common labourers or general labourers"
99140 "Day labourers (e.g journalier)"
99150 "Worker nfs"
99200 "Factory labourers (unspecified)"
99300 "Occupational title unclassifiable"
99420 "Assistants nfs"
99430 "Helpers nfs"
99440 "Helpers of relative or helping at home"
99450 "Apprentices nfs"
99500 "Ambiguous responses"
99998 "Alternative occupation (Sweden)"
99999 "No occupation/Unknown"
0 "not coded yet"
19400 "Personnel and occupational specialists".
MISSING VALUES occhisco (99999).

VALUE LABELS hhsize.
MISSING VALUES hhsize ().

VALUE LABELS place
040000060201001 "Aflenz Markt"
040000061314001 "Stanz im Mürztal/Brandstattgraben"
040000061314002 "Stanz im Mürztal/Dickenbach"
040000060202001 "Aflenz/Döllach"
040000060202002 "Aflenz/Dörflach"
040000060202003 "Aflenz/Draiach"
040000060635001 "Raaba/Dürwagersbach"
040000060219003 "Thörl/Einöd"
040000060202004 "Aflenz/Feistring"
040000061314003 "Stanz im Mürztal/Fladenbach"
040000061314004 "Stanz im Mürztal/Fochnitz"
040000060202005 "Aflenz/Graßnitz"
040000060202006 "Aflenz/Graßnitz-Seebach"
040000060219004 "Thörl/Hinterberg"
040000061314005 "Stanz im Mürztal/Hollersbach"
040000060202007 "Aflenz/Jauring"
040000060219005 "Thörl/Margarethenhütte"
040000061315001 "Veitsch/Niederaigen"
040000060219001 "Thörl/Palbersdorf"
040000061314006 "Stanz im Mürztal/Possegg"
040000060635002 "Raaba"
040000061314007 "Stanz im Mürztal/Retschgraben"
040000061314008 "Stanz im Mürztal/Sonnberg"
040000060219002 "Thörl"
040000060202008 "Aflenz/Tutschach"
040000061314009 "Stanz im Mürztal/Unteralm"
040000070629001 "Tösens"
040000070604001 "Fließ/Dorf"
040000070605001 "Flirsch"
040000070607001 "Grins/Gmar and Grist"
040000070604004 "Fließ/Hochgallmigg"
040000070608001 "Ischgl"
040000070608002 "Ischgl/Mathon"
040000070604005 "Fließ/Niedergallmigg"
040000070618001 "Pians"
040000070604006 "Fließ/Piller"
040000070618002 "Pians/Quadratsch"
380000021027001 "Reschen"
040000070624001 "Serfaus"
040000070604002 "Fließ/Berg"
040000070621001 "St. Anton am Arlberg"
040000070621002 "St. Anton am Arlberg/St. Jakob"
040000070628001 "Tobadill"
040000070604003 "Fließ/Urgen"
040000070619001 "Prutz"
643061217867004 "Lokna"
643061217845001 "Mishino"
643061217867001 "Slabotka"
643061217839001 "Krasnoje Sobakino"
643061250850001 "Pokrovskoye"
643061240869004 "Ozeriha"
643061240551001 "Saray"
276005122000001 "Höhscheid"
703000525219001 "Šarišské Dravce"
703000526240001 "Silická Jablonica"
703000500488001 "Lukáčovce"
703000528862001 "Medzianky "
703000520471001 "Medzilaborce"
703000520829001 "Ostronica"
703000523950001 "Švábovce"
703000524611001 "Kamenica "
348000002668001 "Kecskemét/Czethal"
348000002668002 "Kecskemét/Csalános "
348000002668003 "Kecskemét/Halesz"
348000002668004 "Kecskemét/Monostorpuszta"
348000002668005 "Kecskemét/Nyírpuszta"
348000001693001 "Orgovány"
348000002668006 "Kecskemét/Széktó"
348000002668007 "Kecskemét/Téglás"
348000002668008 "Kecskemét/Úrréti puszta"
703000518174001 "Bacurov"
703000508675001 "Brusno"
703000508438001 "Rudlová"
703000518760001 "Sielnice"
348000502154001 "Deménd"
348000001734001 "Kiscsécs"
348000001144001 "Kisrozvágy"
348000002375001 "Semjén"
348000002092001 "Kisigmánd"
348000003351001 "Szák"
348000003022001 "Tardos"
348000000544001 "Újszőny"
642000140244001 "Benesat"
642000140823001 "Crişeni"
642000140583001 "Archid"
642000140583002 "Coșeiu"
642000107234001 "Corni"
642000140958001 "Sancraiul Silvaniei"
348000002395001 "Mohács"
348000002699001 "Tóthszentgyörgy"
348000001640001 "Tóthújfalu"
642000006627001 "Bradesti"
642000116545001 "Deda"
642000116590001 "Damieni"
642000119331001 "Sangeorgiu de Padure"
642000115959001 "Voiniceni"
642000118281001 "Santandrei"
642000085840001 "Sânsimion"
703000580554001 "Cenkovce"
703000502359001 "Iňa"
703000502651001 "Plavé Vozokany"
703000501662001 "Janíky - Horné Janíky"
703000555860001 "Veľký Lapáš"
703000556653001 "Radošovce"
703000501492001 "Blatná na Ostrove"
703000505561001 "Tesáre"
703000501336001 "Radvaň nad Dunajom  "
380000058091003 "Rome/San Marcello"
276005515000001 "Albachten Niederort"
250000001026001 "Bâgé-le-Châtel"
250000015021001 "Boisset"
250000018022001 "Barlieu"
250000029073001 "Guimaëc"
250000034027001 "Beaulieu"
250000046030001 "Bio"
250000047019001 "Bajamont"
250000055025001 "Baâlon"
250000064097001 "Barzun"
250000065099001 "Bordères-Louron"
250000086018001 "Basses"
276008237040001 "Betra"
276008417051001 "Bietenhausen"
276008417025002 "Bittelbronn mit Henstetten"
276008237040002 "Dettensee"
276008237040003 "Dettingen"
276008237040004 "Dettlingen"
276008237040006 "Dießen mit Haidenhof"
276008325057002 "Fischingen mit Wehrstein"
276008417025005 "Hart"
276008417051002 "Höfendorf"
276008237040008 "Priorberg"
276008417025008 "Stetten"
276008417025009 "Trillfingen"
276008417025007 "Imnau"
276005515000002 "Albachten Oberort"
642000178689001 "Adunații de Olteni"
642000046554001 "Adunații ot Poșta Călmățui"
642000125873001 "Bobicești"
642000102213001 "Buda Crinceni"
642000044560001 "Cazasu"
642000068280001 "Cazați"
642000126647001 "Comanca"
642000066768001 "Conțeștii de Sus"
642000102543001 "Copăcenii Bojoreni"
642000153543001 "Coturani"
642001526617001 "Crăngeni"
642000046803001 "Cremenea"
642000151932001 "Crevenicu Mare"
642000174496001 "Cucoiul"
642000066526001 "Drăgodănești"
642000065869001 "Edera de Jos"
642000128105001 "Enoșești"
642000082680001 "Florești"
642000047006001 "Fundurile"
642000074750001 "Gabru de Sus"
642000014851001 "Gălășești"
642000103130001 "Găneasa"
642000130302001 "Găvănești"
642000100521001 "Giurgiu"
642000014085001 "Groși"
642000135431001 "Hibude"
642000126674001 "Horezu"
642000133919001 "Lapoșu Nou"
642000699640001 "Leamna"
642000104047001 "Letca Noă"
642000048842001 "Macrina"
642000126022001 "Mănăstirea Brâncoveni"
642000152760001 "Merișani"
642000070174001 "Mileștii de Sus"
642000069900001 "Moflea"
642000013524001 "Nămăești"
642000100610001 "Olteniţa"
642000071547001 "Panaghiia de Jos"
642000172812002 "Piatra Iepii"
642000049313001 "Plopeasa"
642000104387001 "Poenarii Niculescului"
642000094161001 "Pribegi"
642000104831001 "Roata"
642000102473001 "Runcu"
642000133394001 "Rușii și Fulga"
642000049206001 "Săpoca"
642000125347001 "Slatina"
642000043563001 "Slobozia Măcsineni"
642000066401001 "Socetu"
642000101564001 "Sterianu Petrescului"
642000044328001 "Strămbu"
642000129184001 "Studina"
642000104582001 "Surlarii Rumâni și Sârbi"
642000043073001 "Tătari"
642000154834001 "Țigăneștii Dașliului"
642000176686001 "Vărcăneasa"
642000044505001 "Vizirii de Sus"
642000019999001 "Vlădeștii de Jos"
642000166985001 "Vulturești"
642000130231001 "Vultureștii de Sus"
642000070673001 "Zvorcani"
804612388090101 "Białozorka"
804612588180101 "Dederkały"
804562468980501 "Horyńgród"
804682035560001 "Jampol"
804612348290101 "Katerynburg"
804612248480101 "Kołodno"
804612381010001 "Łanowce"
804562308560101 "Niewirków"
804612348760101 "Stary Oleksieniec"
804612248810101 "Stary Wiśniowiec"
804612588950101 "Szumbar"
804612388300101 "Wyszgoródek"
818000000001001 "unknown place in region Antaiopolite"
818000000002001 "Tanyaithis"
250000010025001 "Bagneux-la-Fosse"
250000014394001 "Maizières"
250000021241001 "Échevronne"
250000044150001 "Saint-Aignan-Grandlieu"
250000052366001 "Ormancey"
250000060188001 "Cuise-la-Motte"
250000062403001 "Hallines"
250000071017001 "Ballore"
250000072381001 "Voivres-lès-le-Mans"
250000076460001 "Nesle-Normandeuse"
250000077015001 "Baby"
250000083008001 "Bagnols-en-Forêt"
250000085013001 "Bazoges-en-Paillers"
250000090094001 "Sevenans"
528000000687001 "Arnemuiden"
528000000654001 "Baarland en Bakendorp"
528000000717001 "Biggekerke"
528000000654002 "Borssele"
528000000654003 "Driewegen en Coudorpe"
528000000664001 "Goes"
528000000654004 "Heinkenszand"
528000000654005 "Hoedekenskerke"
528000000678001 "Kapelle en Biezelinge"
528000000687002 "Kleverskerke"
528000000664002 "Kloetinge"
528000000703001 "Kruiningen"
528000000654006 "Nisse"
528000000718001 "Oost-Souburg"
528000000654007 "Oudelande"
528000000654008 "Ovezande"
528000000678002 "Schore en Vlake"
528000000717002 "Serooskerke (Walcheren)"
528000000654009 "s-Gravenpolder"
528000000664003 "s-Heer Arendskerke"
528000000654010 "s-Heerenhoek"
528000000678003 "Wemeldinge"
528000000718002 "West-Souburg"
528000000664004 "Wolphaartsdijk"
528000000703002 "Yerseke"
528000000717003 "Zoutelande"
804052418420101 "Obodivka"
804052048860301 "Jalanec"
804052048300601 "Krušinivka"
804052048540601 "Luguvate"
804052048400301 "Potašnja"
804052418420201 "Tatarivka"
804052328200101 "Hristište"
804052048130301 "Ljubašivka"
804052198440101 "Kriklivec"
804052048420301 "Pjatkivka"
804052508480101 "Rogizka"
643046248870066 "Abakshino"
643046234802009 "Afanasovo"
643046411000001 "Alekseevo"
643046243825001 "Avsunino"
643046234807015 "Beleninovo"
643046206825002 "Bochevino"
643045290568001 "Chagina"
643046206825008 "Chechevilova"
643045263564001 "Chernitsyno"
643046411000002 "Denisievo"
643046222804005 "Dubenki"
643046248888013 "Fominskaya"
643045263564002 "Kaloshino"
643045290558001 "Kapotnya"
643046411000003 "Kishkina"
643046483000001 "Kobyl'ya luzha"
643046206825016 "Leonovo"
643046206825011 "Lidino"
643045280594001 "Medvedkovo"
643046253831001 "Meshherino"
643046248891007 "Mikhailovskaya sloboda"
643046248870006 "Mikheevo"
643046243825008 "Mistsevo"
643046438000001 "Mityaevskaya sloboda"
643046248888007 "Nikitskoe"
643046206825009 "Nikol'skoe"
643046248501001 "Novorozhdestveno (novoe)"
643046206843009 "Novotroitskaya"
643046242501001 "Ozery"
643046234807014 "Pogorelki"
643045280594002 "Poluyurlova"
643046243825007 "Ponarino"
643046206825014 "Pushkino"
643045280594003 "Raevo"
643045290558002 "Ryazantsevo"
643045280594004 "Saburovo"
643046438000002 "Sandyri"
643046206802006 "Shelepino"
643046206501001 "Troitsko-Zotovo"
643046206825007 "Vyrypaevo"
643046248888012 "Yan'shino"
643045280594005 "Yurlova"
643046243831020 "Zevnevo"
040000030301001 "Waidhofen a.d. Ybbs"
040000040614001 "Pregarten/Aist"
040000040614008 "Pregarten/Gmeinerhof"
040000040614002 "Pregarten/Greising"
040000040614003 "Pregarten/Greisingberg"
040000040614004 "Pregarten/Halmenberg"
040000040614005 "Pregarten/Meitschenhof"
040000040614006 "Pregarten"
818000000003001 "Apias"
818000000003002 "Arsinoe"
818000000003003 "Bacchias"
818000000003004 "Dionysias"
818000000003005 "Ibion Eikosipentarouron"
818000000003006 "Karanis"
818000000003007 "Kerk(esoucha?)"
818000000003008 "Kerkesis"
818000000003009 "Mendes"
818000000003010 "Nilopolis"
818000000003011 "Philadelphia"
818000000003012 "Philagris"
818000000003013 "Polemon Divisio"
818000000003014 "Samareia"
818000000003015 "Soknopaiou Nesos"
818000000003016 "Tebtunis"
818000000003017 "Theadelphia"
818000000003018 "unknown place in the region  of Arsinoite"
818000000004001 "Peptaucha"
818000000005001 "Trimeithis"
818000000006001 "Ankyronpolis"
688000034300009 "Arandjelovac"
688000034300024 "Banja"
688000034300019 "Brezovac"
688000034300016 "Gornja Trešnjevica"
688000034300017 "Vukosavci"
191000005983001 "Čepikuće"
191000005983002 "Cotesi"
191000005983003 "Lisac"
191000005983004 "Mravnica"
191000005983005 "Podgora"
191000005983006 "Podimoć"
191000005983007 "Smokovljani"
191000005983008 "Točionik"
191000005983009 "Trnova"
191000005983010 "Trnovica"
191000001988001 "Dragavine"
191000001988002 "Gojanovici"
191000001988003 "Kuna"
191000001988004 "Ljuta"
191000001988005 "Lovorno"
191000001988006 "Mihanići"
191000001988007 "Moljevina"
191000001988008 "Nartice"
191000001988009 "Nosanovici"
191000001988010 "Oprasi"
191000001988011 "Pridvorje"
191000001988012 "Rudeš"
191000001988013 "Vignji"
276003456025001 "Wietmarschen"
276005554040001 "Raesfeld"
276005566016001 "Bevergern"
276005562004001 "Castrop-Rauxel"
276005570008001 "Beckum"
276007334017001 "Lingenfeld"
276007333019001 "Eisenberg (Pfalz, Stadt)"
300001040801001 "Kythira (Cerigo)"
643045290554001 "Vykhino"
792100000212001 "Istanbul/Beşiktaş"
792100000212002 "Istanbul/Eminönü"
792100000212003 "Istanbul/Fatih"
792100000216001 "Istanbul/Üsküdar"
792100000212004 "Istanbul/Şişli"
276008426090001 "Oggelshausen"
276008135010001 "Dischingen"
276008135010002 "Iggenhausen"
276008135010003 "Schrezheim"
276008135010004 "Hochstatt"
276008135010005 "Seegmühl"
276008421000001 "Gögglingen"
203000554821013 "Nová Běla, Mitrovice"
276015002000001 "Halle/Saale"
818000000006002 "Herakleopolis"
818000000006003 "Machor"
818000000007001 "Hermopolis"
818000000008001 "Lykopolis"
818000000009001 "Memphis"
818000000010001 "Oxyrhynchus"
818000000010002 "Sinary"
818000000010003 "Talao"
818000000011001 "unknown place in the region of Prosopite"
056000034003001 "Avelgem"
056000037002001 "Dentergem"
056000037011001 "Egem"
056000036008001 "Emelgem"
056000034022001 "Heule"
056000036007001 "Ingelmunster"
056000036008002 "Izegem"
056000036008003 "Kachtem"
056000037015001 "Kanegem"
056000037002002 "Markegem"
056000037007001 "Meulebeke"
056000037002004 "Oeselgem"
056000037017001 "Ooigem"
056000037010001 "Oostrozebeke"
056000037011002 "Pittem"
056000036015001 "Rumbeke"
056000037017003 "Sint-Baafs-Vyve"
056000037015002 "Tielt"
056000037002003 "Wakken"
056000034040001 "Waregem"
056000037017002 "Wielsbeke"
056000034042001 "Zwevegem"
112000225030001 "Czarnawazyckim"
112000225154001 "Szereszowie"
616306091901001 "Wlodawa"
616306091508001 "Wohynia"
112000225083001 "Wolozyn"
440000003910001 "Wylkowyszki"
112000222370001 "Kamienia"
112000222365001 "Rakow"
040000600910001 "Fötschach"
040000600910002 "Gottsbach"
040000600910003 "Leistach"
040000600910004 "Pichl"
040000600910005 "Preg"
040000600910006 "Preggraben"
040000600910007 "Ritzendorf"
040000600910008 "Schütt"
040000600910009 "St.Benedikten"
040000600910010 "St.Lorenzen"
040000600910011 "Untermur"
100000000597001 "Arda"
100000004801001 "Bogutevo"
100000023025001 "Barutica"
100000067547001 "Smiljan"
100000067653001 "Smoljan"
100000069345001 "Stojkite"
100000073105001 "Trigrad"
100000080371001 "Čepelare"
100000083274001 "Široka laka"
203000554821001 "Moravska Ostrava"
203000554821002 "Vitkovice"
203000554821003 "Proskovice"
203000554821004 "Nová Bela"
203000554821005 "Stará Bela"
203000554821006 "Hrabová"
203000554821007 "Hrabuvka"
203000554821008 "Nová Ves"
203000554821009 "Privoz"
203000554821010 "Výskovice"
203000554821011 "Zábreh"
203000554821012 "Mariánské Hory"
203000598348001 "Krmelín"
203000598348002 "Svetlov"
203000598348003 "Starý Dvur"
203000598739001 "Stará Ves"
250000024053001 "Boulazac"
250000033394002 "St. Emilion"
250000033504004 "Sauternes"
250000033523001 "Targon"
250000064483001 "St. Jean de Luz"
250000064501002 "Sallespisse"
276001051060001 "Uedemerbruch"
276001051060002 "Keppeln"
276003153012001 "Seesen"
276003154005001 "Frellstedt"
276003154017001 "Räbke"
276003154026001 "Wolsdorf"
276003154030001 "Lelm"
276003453001001 "Barßel"
276003453003001 "Cappeln"
276003453005001 "Emstek"
276003453006001 "Essen"
276003453007001 "Markhausen"
276003453010001 "Lindern"
276003453011001 "Löningen"
276003453012001 "Molbergen"
276003453013001 "Scharrel"
276003453013002 "Ramsloh"
276003453013003 "Strücklingen"
276003454005001 "Börger"
276003454008001 "Dörpen"
276003454010001 "Emsbüren"
276003454020001 "Heede"
276003454029001 "Lathen"
276003454032001 "Schepsdorf"
276003454033001 "Lorup"
276003454041001 "Aschendorf"
276003454041002 "Papenburg"
276003454044001 "Rhede"
276003454045001 "Salzbergen"
276003454047001 "Sögel"
276003454057001 "Werlte"
276003460001001 "Vestrup"
276003460001002 "Bakum"
276003460004001 "Lutten"
276003460004002 "Goldenstedt"
276003460006001 "Lohne"
276003460008001 "Steinfeld"
276003460009001 "Vechta"
276003460009002 "Oythe"
276003460009003 "Langförden"
276003460010001 "Visbek"
276005162024001 "Neuss"
276005554004001 "Ahaus"
276005554004002 "Barle"
276005554004003 "Ortwick"
276005554004004 "Quantwick"
276005554004005 "Sabstätte"
276005554012001 "Borken"
276005554012002 "Bührdarp"
276005554012003 "Große Klucht"
276005554012004 "Grütlohn"
276005554012005 "Haus Pröbstinck"
276005554012006 "Homer"
276005554012007 "Hoxvelt"
276005554012008 "Krukelinck"
276005554012009 "Leyhaußer Klucht"
276005554012010 "Marbeck"
276005554012011 "Newe Klucht"
276005554012012 "Rhebrugge"
276005554012013 "Venne Klucht"
276005554012014 "Wehrte"
276005554012015 "Westenbrocken"
276005566076001 "Rheine"
276005570020001 "Enniger"
276005570020002 "Ennigerloh"
276005570020003 "Ostenfelde"
276005570020004 "Westkirchen"
276005570028001 "Oelde"
276005570048001 "Diestedde"
276005570048002 "Liesborn"
276005570048003 "Wadersloh"
276005958044001 "Allendorf"
276005958044002 "Amecke"
276005958044003 "Hagen"
276005958044004 "Stockum"
276005958044005 "Illingheim"
276005958044006 "Dörnholthausen"
276005958044007 "Seidfeld"
276005958044008 "Bruchhausen"
276005974024001 "Lippborg"
276005974024002 "Herzfeld"
276005974024003 "Assen"
276005974024004 "Brönicke"
276005974024005 "Dorf"
276005974024006 "Ebbeker"
276005974024007 "Frölich"
276005974024008 "Osker"
276005974024009 "Polmer"
276005974024010 "Hovestadt"
276007133103001 "Stromberg"
276007133103002 "Sünninghausen"
276007137221001 "Rhens"
276007137221002 "Waldesch"
276007232123001 "Beilingen"
276007232123002 "Herforst"
276007232123003 "Kälbermühle"
276007232123004 "Laymühle"
276007232123005 "Speichermühle"
276007232123006 "Neuhimrath"
276007232123007 "Hosten"
276007232123008 "Preist"
276008111000001 "Stuttgart"
276008128138001 "Triebsdorf"
276008128138002 "Wohlbach"
616502010603004 "Heidelberg"
276009463000001 "Coburg"
276009473170001 "Untersiemau"
276009473170002 "Scherneck"
276009473170003 "Stöppach"
276009473170004 "Weißenbrunn am Forst"
276009473170005 "Ziegelsdorf"
276009473175001 "Weitramsdorf"
276009473175002 "Schlettach"
276009473175003 "Weidach"
276012067036001 "Beeskow"
276013003000001 "Rostock"
276015082241001 "Krina"
276015089030001 "Schlewipp-Gröna"
276015089030002 "Leau"
276015091375001 "Söllichau"
276015091375002 "Tornau"
276015091375003 "Durchwehna"
276016067019001 "Ernstroda"
276016067023001 "Fröttstedt"
276016067042001 "Laucha"
276016067064001 "Kleintabarz"
276016067064002 "Nonnenberg"
276016067072001 "Rödichen"
276016067072002 "Schnepfenthal"
276016067072003 "Salzmannschule"
276016067083001 "Gospiteroda"
276016073076001 "Cumbach"
380000006175001 "de…Trivelle"
380000006181001 "de Vigazolo"
380000022114001 "de la Mezana"
380000023044001 "Legnago"
380000023044002 "de Villabona"
380000023044003 "de la Ponzina"
380000023044004 "de S. Petro Leniaci"
380000023044005 "de Vangadicia"
380000023044006 "de Vigo"
380000023044007 "de la Mota"
380000023044008 "de…Vigi"
616622436101001 "Schidlitz/Siedlce"
616306121207001 "Woitsdorf"
616430570602001 "Ciswice"
616430570602002 "Wilkowya"
616430572005001 "Macew"
616430570602003 "Felicyanowo"
616432640203001 "Neu-Wedell"
616502010603001 "Petersdorf"
616502010603002 "Hartenberg"
616502010603003 "Kiesewald"
616502041501001 "Ohlau, 2. Stadtbezirk"
616430571701001 "Sobotka"
616622420601001 "Berent/Kościerzyna"
688000034300003 "Orašac"
688000034300012 "Garaši"
688000034300013 "Jelovik"
688000034300015 "Markovac"
688000034300021 "Bukovik"
688000034300023 "Vrbica"
688000034300025 "Kopljare"
688000034300026 "Stojnik"
688000034310022 "Topola"
724000018051001 "Colomera"
724000029051002 "Estepona"
756040000132001 "Hirzel"
756040000142001 "Wädenswil"
276002000000001 "Altona, Købstad"
276001055016006 "Grömitz, Kirchspiel"
276001057044003 "Lammershagen, Gut"
276001058145001 "Schönhorst, Gut"
276001058001001 "Hohenschulen"
276001058135002 "Rendburger Schlossgrund"
276001057024001 "Gross-Harrie, Dorf"
276001057024002 "Klein-Harrie, Dorf"
276001055001001 "Holstendorf, Dorf"
276001055041002 "Süsel, Vorwerk"
276001055044001 "Gronenberg, Vorwerk"
276001055035001 "Luschendorf, Vorwerk"
276001058053001 "Sprengerfeld, Dorf"
276001060088001 "Todesfelde, Dorf"
276001060092001 "Wahlstedt, Dorf"
276001057011002 "Bothkamp, Gut"
276001055041001 "Klein Bockwold, Dorf"
276001055033001 "Johannsdorf, Dorf"
203000561681001 "Steinschönau/Kamenický Šenov"
112000247760001 "Mozyr"
112000222380001 "Miadziol"
112000211817001 "Orzechowo i Prozorki"
440000003330001 "Krakopol"
440000003301001 "Olita"
440000006529001 "Ligumy"
440000006536001 "Linkow"
440000006642001 "Nowe Miasto"
440000006546001 "Pokroie"
440000002902001 "Szawle"
440000007315001 "Komaje"
440000006258001 "Malaty"
440000003408001 "Onikszty"
440000003469001 "Traszkuny"
440000008276001 "Uszpole"
440000008101001 "Wilkomierz"
440000008967001 "Musniki"
440000001316001 "Snipiszki"
440000001314001 "Wilno"
112000213010001 "Szklow"
112000222415001 "Kurzeniec"
112000231335001 "Lipniszki"
112000222340001 "Wolozyn"
112000231102001 "Zuprany"
112000211631001 "Kochanowicz"
112000000000001 "Karolin"
440000008223001 "Polesie"
112000211950001 "Dzisna"
112000211480001 "Sloboda Mikolaiowska"
440000006724001 "Pukniany"
276013003000002 "Kabutzenhof bei Rostock"
276013003000003 "Riekdahl"
276013003000004 "Bramow"
276013003000005 "Dierkow, Dorf des Hospitals zum St. Georg zu Rostock"
276013003000006 "Dierkow im D.A. Toitenwinkel"
276013003000007 "Toitenwinkel, Hausgut"
276013003000008 "Toitenwinkel"
276013003000009 "Evershagen"
276013003000010 "Schmarl, Dorf"
276013003000011 "Schmarl, Hof"
276013003000012 "Lütten Klein"
276013003000013 "Stuthof"
276013003000014 "Bartelsdorf"
276013003000015 "Dalwitzhof"
276013003000016 "Kassebohm"
276013004000001 "Schwerin"
276013004000002 "Ostorf, Dorf"
276013004000003 "Ostorf, Feldmark"
276013004000004 "Haselholz"
276013004000005 "Krebsförden"
276013004000006 "Zippendorf"
276013004000007 "Görries"
276013004000008 "Ostorf, Hof"
276013004000009 "Ostorfer Halse"
276013004000010 "Ostorfer Kaserne (a.d. Schwerin)"
276013004000011 "Schwerin, Ziegelei Gesewinkel"
276013004000012 "Schweriner Fähre im D. A. Schwerin"
276013004000013 "Neumühle"
276013004000014 "Schelfwerder"
276013004000015 "Lankow"
276013004000016 "Groß Medewege"
276013004000017 "Groß Medewege Jaldmark"
276013004000018 "Klosterberg-Ziegelei bei Groß Medewege"
276013004000019 "Klein Medewege im D.A. Schwerin"
276013004000020 "Carlshöhe"
276013004000021 "Paulsdamm"
276013004000022 "Friedrichsthal im D. A. Schwerin"
276013004000023 "Alt Wickendorf"
276013004000024 "Neu Wickendorf"
276013004000025 "Wickendorf (Carlshöhe)"
276013004000026 "Buchholz"
276013004000027 "Kaninchenwerder, Insel"
276013004000028 "Fasanerie"
276013006000001 "Vor Wendorf"
276013006000002 "Mittel Wendorf"
276013006000003 "Hinter Wendorf"
276013006000004 "Lenensruhe"
276013006000005 "Groß Flöte (Wismar)"
276013006000006 "Övelgünne"
276013006000007 "Pachtgut St. Jacobshof"
276013006000008 "Müggenburg"
276013051009001 "Bentwisch"
276013051009002 "Albertsdorf"
276013051009003 "Harmsdorf"
276013051009004 "Klein Bentwisch"
276013051009005 "Klein Albertsdorf"
276013051011001 "Blankenhagen"
276013051011002 "Billenhagen"
276013051011003 "Mandelshagen"
276013051015001 "Pastow"
276013051019001 "Elmenhorst im D. A. Doberan"
276013051020001 "Gelbensande"
276013051020002 "Willershagen, Dorf"
276013051020003 "Willershagen, Hof"
276013051022001 "Graal-Müritz"
276013051037001 "Klein Kussewitz"
276013051037002 "Volkenshagen"
276013051040001 "Klein Stove"
276013051040002 "Gross Schwaß"
276013051041001 "Kröpelin"
276013051041002 "Hanshagen"
276013051041003 "Gut Duggenkoppel"
276013051042001 "Fulgen"
276013051051001 "Gross Stove"
276013051051002 "Niendorf"
276013051051003 "Sildemow, Dorf"
276013051051004 "Sildemow, Hof"
276013051053001 "Wahrstorf im Rostocker District"
276013051054001 "Vogtshagen, Dorf"
276013051054002 "Vogtshagen, Hof, zum Hospital heil. Geist gehörend"
276013051054003 "Vogtshagen, Hof"
276013051054004 "Busterich"
276013051064001 "Kösterbeck"
276013051064002 "Fresendorf im D. A. Toitenwinkel"
276013051064003 "Fresendorf im R. A. Güstrow"
276013051066001 "Rövershagen"
276013051066002 "Landkrug im D. A. Ribnitz"
276013051066003 "Purkshof"
276013051066004 "Behnkenhagen"
276013051066005 "Landkrug im D.A. Ribnitz"
276013051068001 "Oberhof, Hof"
276013051068002 "Oberhof, Meierei"
276013051068003 "Klein Freienholz"
276013051068004 "Groß Freienholz"
276013051086001 "Niederhagen"
276013051086002 "Satow, Hof"
276013051086003 "Büdner Colonie Satow Oberhagen"
276013051086004 "Satow-Oberhagen"
276013051089001 "Damm, Dorf, im D. A. Schwaan"
276013051089002 "Schlage Hospital zum St. Georg zu Rostock"
276013051089003 "Hohen Schwarfs"
276013051089004 "Beselin"
276013051089005 "Kessin"
276013052017001 "Zarnekow"
276013053003001 "Damm, Dorf, im D.A. Dargun"
276013053007001 "Bernitt"
276013053007002 "Neu Bernitt"
276013053017001 "Lissow"
276013053031002 "Devwinkel"
276013053031003 "Bauhof"
276013053031004 "Magdalenenlust"
276013053031005 "Gleviner Burg"
276013053031006 "Primerburg"
276013053031007 "Stasewitzerburg"
276013053031008 "Brunnen"
276013053031009 "Bülower Burg"
276013053031010 "Friedrich-Franz-Eisenbahn"
276013053031011 "Grenzburg"
276013053037001 "Klein Gischow im R. A. Bukow"
276013053086001 "Grünenhagen"
276013053094001 "Lübzin"
276013053094002 "Diedrichshof"
276013053104001 "Boldebuck"
276013054028001 "Eldena"
276013054028002 "Altona"
276013054028003 "Bellevue"
276013054028004 "Eulenkrug im L. A. Grabow Eldena"
276013054045001 "Lehmkuhlen"
276013054054001 "Klein Rogahn im D. A. Schwerin"
276013054054002 "Groß Rogahn, Dorf"
276013054054003 "Groß Rogahn, Hof"
276013054065001 "Lübesse"
276013054065002 "Hasenhäge (bei Schwerin)"
276013054067001 "Gut Gösslow"
276013054067002 "Jessenitz, Hof"
276013054067003 "Jessenitz, Dorf"
276013054067004 "Gut Bandekow im R. A. Schwerin"
276013054084001 "Pampow, Dorf"
276013054084002 "Pampow, Hof"
276013054099001 "Stralendorf, Dorf"
276013054099002 "Stralendorf, Hof"
276013054101001 "Boldela"
276013054111001 "Gut Warlitz"
276013055044001 "Mirow"
276013056004001 "Alt Schwerin"
276013056004002 "Jürgenshof, Gut"
276013056004003 "Alt Schwerin, Glashütte"
276013056004004 "Alt Schwerin, Gut"
276013056004005 "Mönchbusch"
276013056004006 "Ortkrug, Hof, im D. A. Schwerin"
276013056004007 "Jürgenshof"
276013056023001 "Kratz"
276013057002001 "Althagen"
276013057002002 "Niehagen"
276013057022001 "Dierhagen"
276013057022002 "Neu Dierhagen"
276013057022003 "Dändorf"
276013057057002 "Jahnckendorf"
276013057057003 "Carlewitz"
276013057057004 "Bartelshagen"
276013057057005 "Emkenhagen im Kloster Amte Ribnitz"
276013057057006 "Brünkendorf"
276013057057007 "Dänschenburg"
276013057057008 "Kuhlrade"
276013057057009 "Bookhorst"
276013057074001 "Wilmshagen"
276013057074002 "Petersdorf"
276013057074003 "Alteheide"
276013057074004 "Hirschburg"
276013057074005 "Klockenhagen"
276013057074006 "Neuheide"
276013057074007 "Klein Müritz"
276013057074008 "Neuhof"
276013057094001 "Wustrow"
276013057094002 "Barnstorf"
276013058001001 "Alt Meteln im R. A. Schwerin"
276013058001002 "Meteln, Hof"
276013058001003 "Moltenow"
276013058001004 "Neu Meteln"
276013058001005 "Böken im R.A. Schwerin"
276013058003001 "Insel Lieps im Schweriner See, zu Gallentin gehörend"
276013058003002 "Gallentin"
276013058003003 "Bahnhof Kleinen im D. A. Schwerin"
276013058003004 "Kleinen im D. A. Schwerin"
276013058005001 "Groß Wolterdorf"
276013058005002 "Klein Woltersdorf, Erbpachtgut"
276013058007001 "Benz, Dorf, bei Wismar"
276013058007002 "Warkstorf"
276013058007003 "Warkstorf, Erbpachtgut"
276013058007004 "Gut Benz im R. A. Schwerin"
276013058007005 "Preensberg, Erbpachtgut"
276013058016001 "Brüsewitz im R.A. Schwerin"
276013058016002 "Groß Brütz, Gut, im R. A. Schwerin"
276013058016003 "Eulenkrug im R.A. Schwerin"
276013058016004 "Rosenberg im R.A. Schwerin"
276013058016005 "Gottmannsförde"
276013058016006 "Wahrholz"
276013058016007 "Paulmühle"
276013058019001 "Cramonshagen"
276013058019002 "Nienmark"
276013058019003 "Cramon"
276013058020001 "Dalberg im D. A. Schwerin"
276013058020002 "Wendelstorf"
276013058025001 "Steffin, Erbpachtgut"
276013058026001 "Dragun, Dorf"
276013058026002 "Drieberg, Hof"
276013058026003 "Drieberg im D. A. Schwerin"
276013058026004 "Dragun (Neu), Dorf"
276013058029001 "Jamel"
276013058031001 "Gottesgabe"
276013058031002 "Pertinenz Bergfeld"
276013058031003 "Klein Welzin"
276013058031004 "Groß Welzin im R. A. Schwerin"
276013058032001 "Grambow"
276013058032002 "Wendischhof"
276013058032003 "Charlottenthal"
276013058034001 "Grevesmühlen"
276013058049001 "Hornstorf"
276013058049002 "Tannenkathen"
276013058053001 "Klein Trebbow"
276013058053002 "Moorbrink, Meierei"
276013058053003 "Kirch Stück, Hof"
276013058053004 "Kirch Stück"
276013058053005 "Anlage B."
276013058053006 "Groß Trebbow im R. A. Schwerin"
276013058053007 "Barner Stück im R.A. Schwerin"
276013058063001 "Triwalk, Dorf"
276013058063002 "Triwalk, Erbpachtgut Hof"
276013058063003 "Maßlow"
276013058064001 "Lübstorf"
276013058069001 "Klüssendorf, Dorf"
276013058069002 "Klüssendorf, Erbpachtgut Hof"
276013058069003 "Martensdorf, Dorf"
276013058071001 "Mühlen Eichsen"
276013058071002 "Goddin"
276013058071003 "Groß Eichsen"
276013058073001 "Neuburg"
276013058073002 "Kartlow"
276013058073003 "Kartlow, Erbpachtgut Hof"
276013058091001 "Diedrichshagen"
276013058095001 "Seehof"
276013058095002 "Hundorf"
276013058102001 "Frauenmark"
276013058102002 "Neu Frauenmark"
276013058108001 "Zickhusen, Dorf"
276013058108002 "Zickhusen, Erbpachthof"
276013058108003 "Zickhusen, Hof"
276013058108004 "Driespeth im D. A. Schwerin"
276013058109001 "Wisch (Herrschaft Wismar)"
276013058114001 "Dalliendorf"
276013058114002 "Dalliendorf, Zieglerei"
276013058114003 "Dambeck, Dorf"
276013058114004 "Dambeck, Hof, im Amt Schwerin"
276013060001001 "Banzkow"
276013060001002 "Goldenstädt"
276013060001003 "Alt Jamel, Dorf"
276013060001004 "Neu Jamel, Hof"
276013060003001 "Barnin, Dorf"
276013060003002 "Barnin, Hof"
276013060009001 "Cambs im R.A. Schwerin"
276013060009002 "Ahrensboek im R.A. Schwerin"
276013060012001 "Malchow, Dorf"
276013060016001 "Bergrade, Dorf"
276013060016002 "Bergrade, Hof"
276013060035001 "Dinnies im R. A. Sternberg"
276013060036001 "Karbow, Dorf"
276013060036002 "Karbow, Hof"
276013060045001 "Langen Brütz im R.A. Crivitz und Schwerin"
276013060048001 "Zittow im D. A. Schwerin"
276013060048002 "Zittow im R. A. Schwerin"
276013060048003 "Görslow"
276013060048004 "Görslow, Schäferei"
276013060056001 "Parchim"
276013060056002 "Erbpachtmühle"
276013060059001 "Alt-Godern im D.A. Schwerin"
276013060059002 "Godern im D.A. Schwerin"
276013060059003 "Neu-Godern"
276013060060001 "Consrade"
276013060063001 "Raben Steinfeld"
276013060063002 "Raben Steinfeld, Carsthof"
276013060067001 "Stralendorf"
276013060098001 "Matzlow, Dorf"
276013060098002 "Bahlenberg, Dorf"
276013072043001 "Güstrow"
276013073055001 "Zepelin Wulfshagen"
191000001988014 "Žarkovina"
688000037000001 "Krusevac"
040000050201001 "Abtenau"
040000050401002 "Altenmarkt - Dorf"
040000050401001 "Altenmarkt - Land"
040000041201001 "Andrichsfurt"
040000050304001 "Berndorf"
040000050205001 "Dürnberg"
040000040704001 "Ebensee"
040000041005001 "Enns"
040000020518001 "Feistritz"
040000040601001 "Freistadt"
040000090001006 "Wien/Gaudenzdorf"
040000040201001 "Gleink"
040000030908001 "Gmünd"
040000040705001 "Gmunden"
040000090001001 "Wien/Gumpendorf"
040000090001005 "Wien/Herrengasse"
040000050402001 "Hofgastein"
040000090001010 "Wien/Josefstadt"
040000090001009 "Wien/Kaiserebersdorf"
040000050321001 "Koppl"
040000031629001 "Laa an der Thaya"
040000090001008 "Wien/Leopoldsdorf"
040000031303001 "Maria Langegg"
040000041005002 "Moos"
040000090001011 "Wien/Neubau"
040000031929001 "Obergrafendorf"
040000020534001 "Obermühlen"
040000031719001 "Perchtoldsdorf"
040000031644001 "Poysdorf"
040000041414001 "Raab"
040000041005003 "Rhein"
040000090001007 "Wien/Ringturm"
040000050101001 "Salzburg"
040000021001001 "Sirnitz"
040000021007001 "St. Lorenzen"
040000030101001 "Stein"
040000050337001 "Thalgau"
040065063900001 "Tilliach"
040000032131001 "Weinzierl"
040000070940001 "Zell am Ziller"
040000020531001 "Zweinitz"
040000090001003 "Wien/Schottenfeld"
688000011000001 "Belgrade"
528000001728001 "Bladel"
528000000762001 "Deurne"
528000000772001 "Eindhoven"
528000001771001 "Geldrop"
528000001658001 "Heeze"
528000000794001 "Helmond"
528000000855001 "Tilburg".
MISSING VALUES place ().

VALUE LABELS region
643621 "Russia/Ryazan Governorate"
703700 "Eastern Upper Hungary"
348300 "Hungary/Great Plain"
703600 "Middle Upper Hungary"
348100 "North-Eastern Hungary"
348500 "Hungary/Northern Transdanubia"
642110 "Hungary/Partium"
348700 "Hungary/Southern Transdanubia"
642120 "Hungary/Transylvania"
703200 "Western Upper Hungary"
250711 "France/Département Ain"
250722 "France/Département Cantal"
250241 "France/Département Cher"
250522 "France/Département Finistère"
250813 "France/Département Hérault"
250625 "France/Département Lot"
250623 "France/Département Lot-et-Garonne"
250412 "France/Département Meuse"
250626 "France/Département Hautes-Pyrénées"
250534 "France/Département Vienne"
642227 "Wallachia/district Slam-Râmnic"
642221 "Wallachia/district Brăila"
642222 "Wallachia/district Buzău"
642315 "Wallachia/district Ialomiţa"
642318 "Wallachia/district Săcuieni"
642322 "Wallachia/district Ilfov"
642316 "Wallachia/district Prahova"
642313 "Wallachia/district Dâmboviţa"
642314 "Wallachia/district Vlaşca"
642319 "Wallachia/district Muşcel"
642311 "Wallachia/district Argeş"
642317 "Wallachia/district Teleorman"
642414 "Wallachia/district Olt"
642416 "Wallachia/district Romanaţi"
642415 "Wallachia/district Vâlcea"
642411 "Wallachia/district Dolj"
642413 "Wallachia/district Mehedinţi"
642412 "Wallachia/district Gorj"
804031 "Russia/Roman Catholic Diocese of Luck"
818100 "Roman Empire/Province of Egypt"
250511 "France/Département Loire-Atlantique"
250214 "France/Département Haute-Marne"
250224 "France/Département Oise"
250302 "France/Département Pas-de-Calais"
250263 "France/Département Saône-et-Loire"
250514 "France/Département Sarthe"
250102 "France/Département Seine-et-Marne"
250825 "France/Département Var"
250515 "France/Département Vendée"
250434 "France/Territoire de Belfort"
250232 "France/Département Seine-Maritime"
250025 "France/Département Bouches-de-l’Escaut"
250026 "France/Département Bouches-du-Rhin"
040400 "Habsburg Empire/Duchy of Carinthia"
040500 "Habsburg Empire/Duchy of Styria"
040600 "Habsburg Empire/Archduchy of Upper Austria"
040700 "Habsburg Empire/Duchy of Salzburg"
040800 "Habsburg Empire/Princely County of Tirol with Vorarlberg"
191400 "Habsburg Empire/City of Zagreb"
191910 "Croatia/Roman Catholic Diocese of Dubrovnik"
203700 "Habsburg Empire/Margraviate of Moravia"
276030 "Habsburg Empire/Anterior Austria"
276250 "Germany/Roman Catholic Diocese of Speyer"
276430 "Germany/Prince-Bishopric of Münster/Oberstift"
276431 "Germany/Prince-Bishopric of Münster/Niederstift"
276501 "Germany/Kingdom of Hanover"
300910 "Greece/Ionian Islands"
336001 "Vatican/City of Rome"
756022 "Switzerland/Canton Fribourg"
276570 "Germany/Principality of Calenberg-Göttingen"
276571 "Germany/Principality of Grubenhagen"
643451 "Russia/Moscow Governorate"
804021 "Russia/Braclav Governorate"
380301 "Italy/Republic of Venice"
792340 "Ottoman Empire/Vilayet of Constantinople/Istanbul"
276045 "Germany/Roman Catholic Diocese of Constance"
276765 "Germany/Duchy of Anhalt-Bernburg"
276040 "Germany/Kingdom of Württemberg"
276930 "Germany/Government District of Danzig"
276960 "Germany/Government District of Posen"
250212 "France/Département Aube"
250251 "France/Département Calvados"
250261 "France/Département Côte-d'Or"
368001 "Babylonia/Nippur province"
616621 "Poland-Lithuania/Warmia"
616411 "Poland-Lithuania/Greater Poland"
616611 "Poland-Lithuania/Kujavia"
616412 "Poland-Lithuania/Ostrzeszow County"
616111 "Poland-Lithuania/Wielunskie County"
616211 "Poland-Lithuania/Krakowskie (Lesser Poland)"
616221 "Poland-Lithuania/Silesia"
616311 "Poland-Lithuania/Chelmska Land"
804221 "Poland-Lithuania/Podolia"
804061 "Poland-Lithuania/Zhytomyr County"
112501 "Poland-Lithuania/Central Belarus"
112101 "Poland-Lithuania/Polesia"
100601 "Bulgaria/Rhodope region"
056401 "Belgium/Départment de la Lys"
112502 "Poland-Lithuania/Minsk Voivodeship"
112102 "Poland-Lithuania/Brest Litewski Voivodeship"
112601 "Poland-Lithuania/Witebsk Voivodeship"
112602 "Poland-Lithuania/Połock Voivodeship"
440001 "Russia/Vilna Governorate"
440201 "Russia/Kovno Governorate"
440202 "Poland-Lithuania/Troki Voivodeship"
440002 "Poland-Lithuania/Wilno Voivodeship"
250611 "France/Département Dordogne"
250612 "France/Département Gironde"
250615 "France/Département Pyrénées-Atlantique"
276010 "Germany/Government District of Sigmaringen"
276231 "Germany/Government District of Trier"
276232 "Germany/Government District of Koblenz"
276420 "Germany/Government District of Düsseldorf"
276421 "Germany/Government District of Münster"
276422 "Germany/Government District of Arnsberg"
276531 "Germany/Duchy of Braunschweig"
276600 "Germany/Duchy of Schleswig"
276610 "Germany/Duchy of Holstein"
276620 "Germany/Grand Duchy of Mecklenburg-Schwerin"
276751 "Germany/Government District of Merseburg"
276786 "Germany/Duchy of Sachsen-Coburg"
276788 "Germany/Duchy of Sachsen-Gotha"
276810 "Germany/Government District of Potsdam"
276811 "Germany/Government District of Frankfurt"
276881 "Germany/Government District of Breslau"
276882 "Germany/Government District of Liegnitz"
688310 "Serbia/Jasenički District"
724600 "Spain/Andalucía"
756040 "Switzerland/Canton Zürich"
203410 "Bohemia/Roman Catholic Diocese of Leitmeritz/Litoměřice"
276560 "Germany/County of Bentheim"
040200 "Habsburg Empire/Archduchy of Lower Austria"
688510 "Serbia/Kruševački District"
688100 "Northern Serbia".
MISSING VALUES region ().

VALUE LABELS perwt.
MISSING VALUES perwt ().

VALUE LABELS hhwt.
MISSING VALUES hhwt ().

VALUE LABELS gq
1 "Household with 0-4 persons unrelated to the head"
2 "Household with 5-9 persons unrelated to the head"
5 "Households with 10 or more persons unrelated to the head, and group quarters under British rule"
6 "Households with 10 or more persons unrelated to the head, but not group quarters under British rule"
9 "unknown".
MISSING VALUES gq (9).

VALUE LABELS urban
1 "rural"
2 "urban"
9 "unknown".
MISSING VALUES urban (9).

VALUE LABELS presence
4 "double entry"
0 "not recorded"
1 "present"
2 "absent"
3 "obviously dead"
9 "unknown".
MISSING VALUES presence (0 9).


EXECUTE.
